#
# spec file for package soapy-remote
#
# Copyright (c) 2021 SUSE LLC.
# Copyright (c) 2017, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soapy_modver 0.8
%define soapy_modname soapysdr%{soapy_modver}-module-remote

Name:           soapy-remote
Version:        0.5.2
Release:        4.4
Summary:        Remote device support for Soapy SDR
License:        BSL-1.0
Group:          Productivity/Hamradio/Other
Url:            https://github.com/pothosware/SoapyRemote/wiki
#Git-Clone:     https://github.com/pothosware/SoapyRemote.git
Source:         https://github.com/pothosware/SoapyRemote/archive/%{name}-%{version}.tar.gz
Patch0:	harden_SoapySDRServer.service.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(SoapySDR)

%description
A Soapy module that supports remote devices within the Soapy API.

%package -n %{soapy_modname}
Summary:        Remote device support for Soapy SDR
Group:          System/Libraries
# soapysdr0.7-module-remote needs to be force dropped
Conflicts:      soapysdr0.7-module-remote
# Add 'Provides/Obsoletes' entries for future updates
Provides:       soapy-remote-module = %{soapy_modver}
Obsoletes:      soapy-remote-module < %{soapy_modver}

%description -n %{soapy_modname}
A Soapy module that supports remote devices within the Soapy API.

%package server
Summary:        Server for remote device support for Soapy SDR
Group:          Productivity/Hamradio/Other
# The server part was split, a 'Conflicts' line is also needed here.
Conflicts:      soapysdr0.7-module-remote

%description server
A server that supports remote devices for the Soapy SDR. 
This package is intended to run on the system the sdr device is
connected to.

%prep
%autosetup -p1 -n SoapyRemote-%{name}-%{version}

%build
%cmake
make VERBOSE=1 %{?_smp_mflags}

%install
%cmake_install

mkdir %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcSoapySDRServer

%pre server
%service_add_pre SoapySDRServer.service

%post server
%service_add_post SoapySDRServer.service

%preun server
%service_del_preun SoapySDRServer.service

%postun server
%service_del_postun SoapySDRServer.service

%files -n %{soapy_modname}
%license LICENSE_1_0.txt
%doc Changelog.txt README.md
%dir %{_libdir}/SoapySDR/
%dir %{_libdir}/SoapySDR/modules%{soapy_modver}
%{_libdir}/SoapySDR/modules%{soapy_modver}/libremoteSupport.so

%files server
%license LICENSE_1_0.txt
%doc Changelog.txt README.md
%{_bindir}/SoapySDRServer
%{_sbindir}/rcSoapySDRServer
%{_mandir}/man1/SoapySDRServer.1%{ext_man}
%{_prefix}/lib/sysctl.d/SoapySDRServer.conf
%{_unitdir}/SoapySDRServer.service

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Wed Nov 17 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_SoapySDRServer.service.patch
* Wed Oct 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Also make sure soapy-remote-server replaces
  soapysdr0.7-module-remote.
* Tue Oct 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix installation conflicts with soapysdr0.7-module-remote.
- Add Provides/Obsoletes to avoid issues with future updates.
* Thu Jul 22 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- New package soapysdr-remote-server splitted off.
- Systemd files installed as a part of server package.
* Tue Jul  6 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- SoapySDR version bumped to 0.8
* Tue Feb 23 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.5.2
  * Support more than 31 clients in SSDP endpoint
  * Handle cases where avahi client is null
  * Handle EINTR case for SSDP server select
  * Fix the scale in CS12 - CF32 conversion
  * Protect getServerURLs from re-entrant calls
* Mon Jan 28 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Sun Jan 27 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 0.5.1
  * Fix SoapyLogAcceptor not closing sockets on shutdown
  * Report socket creation errors within SoapyRPCSocket
  * MDNS timeout for OSX when no servers are available
  * Added explicit compile flags for MSVC needed by common
  * Compilation fixes for strerror_r API differences
* Sat Nov 10 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update soapy-module version 0.6 -> 0.7
- Update to version 0.5.0
  * Extract repository version and print in SoapySDRServer
  * Support stream hardware acceleration with protocol none
  * Support for DNS-SD publishing and discovery with avahi
- Update to version 0.4.4
  * Report error for SoapyRPCSocket close() failure
  * SoapyLogAcceptor fix shutdown when connection is lost
  * SoapyRPCUnpacker fix select logic for small timeouts
* Fri Jun  8 2018 wk@ire.pw.edu.pl
- Update to version 0.4.3
  + Added missing remote:prot key to getStreamArgsInfo()
  + Additional timeout for first connect due to ARP delay
  + Disable LogAcceptor during discovery in Release mode
  + SSDP should be quiet when periodic events are disabled
  + Server listener checks socket status and exits on error
  + Additional timeout for discovery and logger unpackers
  + Improved error logger messages with associated url
  + Parameterized connect timeout with remote:timeout arg
  + Reverted accidental change to default timeout constant
* Tue Aug  1 2017 mardnh@gmx.de
- Update to version 0.4.2
  + Fixed timeout problem in log acceptor receiver loop
  + Added server check for slow calls and longer timeout
  - This also resolves timeout errors for lengthy calls
  + Added network-online.target for systemd service script
* Fri Jun  9 2017 mardnh@gmx.de
- Update to version 0.4.1
  + Added timeout for logger connect and control unpacker
  + Fixed error log formatting in the client log acceptor
* Fri May  5 2017 mardnh@gmx.de
- Update to version 0.4.0
  + Added support for frequency corrections for fine adjustments
  + Added support forgetSampleRateRange() for continuous ranges
  + Added support for CF32 local format with CS12 remote format
  + Added support for CS16 local format with CS12 remote format
  + Added support for CS16 local format with CS8 remote format
  + readStream thread support for SOAPY_SDR_END_ABRUPT flag
  + readStream thread apply second SOAPY_SDR_END_BURST flag
  + Added timeout to socket connect and factory calls
  + Support range with step size (backwards compatible)
  + Added tcp support for streaming via remote:prot=tcp
  + Support for bulk register read/write interface APIs
* Wed Apr 19 2017 mardnh@gmx.de
- renamed packages according the debian package name from upstream
* Fri Apr 14 2017 mardnh@gmx.de
- Update to version 0.3.2 (tagged release)
- renamed package from SoapyRemote to soapy-remote
- specfile cleanup
* Tue Dec  8 2015 mardnh@gmx.de
- Update to version 0.1.0.git1448155900.71f7183:
  + remote: support apis to query agc and clock rates
  + remote: sockaddr class and sento/recvfrom
  + soapy: move url utils into class
  + soapy: forward declare thread in headers
  + soapy: set errno on lookup failure
  + soapy: work on ssdp multicast discovery
  + soapy: moved several calls into info utils
  + soapy: common endpoint class for SSDP
  + remote: should be mostly working now
  + remote: cleanup and search/notify asap
  + remote: generate and reuse type 1 UUID for server
  + remote: fixing up uuid implementation
  + remote: constants for the SSDP connection
  + remote: fix socket calls for msvc types
  + remote: SSDP endpoint reference counted singleton
  + remote: v6 multicast fixes and scoped addresses
  + remote: fixes for compiling on OSX
  + remote: fix issue with the forward declares (osx)
  + soapy: SO_REUSEPORT for osx when using multicast
  + remote: send multicast notification for msearch as well
  + remote: logger prints, and common header handler
  + remote: constants for notify alive and byebye
  + remote: client-side arg info calls implemented
  + remote: server-side handling for new info calls
  + remote: support native format in stream calls
  + remote: added new call support to changelog
  + remote: blacklist for failed groups
  + remote: hold a static instance in the client
  + remote: fix lock scope in getStreamArgsInfo()
  + remote: added entry to changelog for SSDP
  + remote: improve error reporting in socket wrapper
  + remote: fix error reporting for other socket calls
  + remote: same reporting for setting buffer size
  + remote: matching error reporting in endpoint
  + remote: osx manual interface selection work-around
  + remote: debug prints for getDefaultIfaceIndex()
  + remote: automatic stream close on SOAPY_REMOTE_UNMAKE
  + remote: default interface filter on ipv6 as well
  + remote: improved logging and socket buffer resize calls
  + remote: fix formatToSize for complex-12bit
  + remote: Support CU8 native conversion to CF32
  + remote: Use formatToSize() from SoapySDR library
  + travis: created a travis ci config for soapy remote
  + travis: added travis build status to readme
  + travis: unit check that driver loads
  + remote: support VC11 by using isspace instead
* Mon Oct 12 2015 mardnh@gmx.de
- initial package
